<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  

  <xsl:template name="ces.header.output">
    <xsl:param name="cesdoc.title"><xsl:call-template name="cesdoc.title"/></xsl:param>
    <xsl:param name="elt.name"><xsl:value-of select="name()"/></xsl:param>
    
    <xsl:variable name="header.creator" select="@creator"/>
    <xsl:variable name="header.status" select="@status"/>
    <xsl:variable name="header.date.created" select="@date.created"/>
    <xsl:variable name="header.date.updated" select="@date.updated"/>

    <html>
      <xsl:call-template name="html.head.output">
	<xsl:with-param name="html.head.title" select="$cesdoc.title"/>
      </xsl:call-template>
      <body>
	<xsl:attribute name="bgcolor"><xsl:value-of select="$html.body.bgcolor"/></xsl:attribute>
	<center><h1><xsl:call-template name="i18n.text">
	      <xsl:with-param name="text.name"><xsl:value-of select="$elt.name"/></xsl:with-param>
	    </xsl:call-template></h1></center>
	
	<blockquote>
	  <xsl:call-template name="i18n.text">
	    <xsl:with-param name="text.name">creator</xsl:with-param>
	  </xsl:call-template> <b><xsl:value-of select="$header.creator"/></b><br/>
	  <xsl:call-template name="i18n.text">
	    <xsl:with-param name="text.name">status</xsl:with-param>
	  </xsl:call-template> <b><xsl:value-of select="$header.status"/></b><br/>
	  <xsl:call-template name="i18n.text">
	    <xsl:with-param name="text.name">date.created</xsl:with-param>
	  </xsl:call-template> <b><xsl:value-of select="$header.date.created"/></b><br/>
	  <xsl:call-template name="i18n.text">
	    <xsl:with-param name="text.name">date.updated</xsl:with-param>
	  </xsl:call-template> <b><xsl:value-of select="$header.date.updated"/></b>
	</blockquote>
	
	<hr noshade="noshade"/>
	
	<xsl:apply-templates select="node()" mode="ces.header"/>
      </body>
    </html>
  </xsl:template>
  
  
  <xsl:template match="*" mode="ces.header">
    <!-- if an element isn't found in this mode, try the default mode -->
    <xsl:apply-templates select="."/>
  </xsl:template>
  
  
  <!-- fileDesc section -->
  
  <xsl:template match="fileDesc" mode="ces.header">
    <xsl:call-template name="cesheader.title"/>
    <table bgcolor="#CCCCCC" width="100%" border="0">
      <xsl:apply-templates select="*" mode="ces.header"/>
    </table>
  </xsl:template>
  
  
  <xsl:template match="titleStmt" mode="ces.header">
    <xsl:apply-templates select="h.title" mode="ces.header"/>
    <xsl:apply-templates select="respStmt" mode="ces.header.titleStmt"/>
  </xsl:template>
  
  
  <xsl:template match="h.title|editionStmt|distributor|pubAddress|availability|projectDesc" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="text()"/></td>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="respStmt" mode="ces.header.titleStmt">
    
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name">respStmt</xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC">
	<table bgcolor="#CCCCCC" width="100%" border="0">
	  <xsl:apply-templates select="respName" mode="ces.header.respStmt"/>
	</table>
      </td>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="respName" mode="ces.header.respStmt">
    <xsl:variable name="next" select="following-sibling::respType"/>
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="left" width="20%"><xsl:value-of select="text()"/></td>
      <td>
	<xsl:call-template name="respStmt.respType">
	  <xsl:with-param name="nodes" select="following-sibling::respType"/>
	</xsl:call-template>
      </td>
    </tr>
  </xsl:template>
  
  
  <xsl:template name="respStmt.respType">
    <xsl:param name="nodes"/>
    <xsl:for-each select="$nodes">
      <li><xsl:apply-templates select="text()"/></li>
    </xsl:for-each>
  </xsl:template>
  
  
  <xsl:template match="extent" mode="ces.header">
    <tr valign="top">
      <td nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td>
	<xsl:apply-templates select="wordCount" mode="ces.header"/>
	<xsl:apply-templates select="byteCount" mode="ces.header"/>
	<xsl:for-each select="extNote">
	  <xsl:call-template name="extent.extNote"/>
	</xsl:for-each>
      </td>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="wordCount" mode="ces.header">
    <xsl:value-of select="text()"/><xsl:call-template name="nbsp"/><xsl:call-template name="i18n.text"><xsl:with-param name="text.name" select="name()"/></xsl:call-template><br/>
  </xsl:template>
  

  <xsl:template match="byteCount" mode="ces.header">
    <xsl:value-of select="text()"/><xsl:call-template name="nbsp"/><xsl:call-template name="i18n.text"><xsl:with-param name="text.name" select="@units"/></xsl:call-template><br/>
  </xsl:template>


  <xsl:template name="extent.extNote">
    <xsl:call-template name="dash.nbsp"/><xsl:value-of select="text()"/><br/>
  </xsl:template>


  <xsl:template match="publicationStmt" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><table bgcolor="#FFFFFF" width="100%" border="0">
	  <xsl:apply-templates select="distributor" mode="ces.header"/>
	  <xsl:apply-templates select="pubAddress" mode="ces.header"/>
	  <xsl:apply-templates select="telephone" mode="ces.header"/>

	  <xsl:call-template name="publicationStmt.misc">
	    <xsl:with-param name="nodes" select="telephone"/>
	    <xsl:with-param name="name">telephone</xsl:with-param>
	  </xsl:call-template>

	  <xsl:call-template name="publicationStmt.misc">
	    <xsl:with-param name="nodes" select="fax"/>
	    <xsl:with-param name="name">fax</xsl:with-param>
	  </xsl:call-template>

	  <xsl:call-template name="publicationStmt.misc">
	    <xsl:with-param name="nodes" select="eAddress"/>
	    <xsl:with-param name="name">eAddress</xsl:with-param>
	  </xsl:call-template>

	  <xsl:call-template name="publicationStmt.idno">
	    <xsl:with-param name="nodes" select="idno"/>
	  </xsl:call-template>
	  
	  <xsl:call-template name="publicationStmt.pubDate">
	    <xsl:with-param name="node" select="pubDate"/>
	  </xsl:call-template>
	  
	  <xsl:apply-templates select="availability" mode="ces.header"/>
	</table>
      </td>
    </tr>
  </xsl:template>
  

  <xsl:template name="publicationStmt.pubDate">
    <xsl:param name="node"/>
    
    <xsl:if test="$node">
      <tr valign="top">
	<td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name">pubDate</xsl:with-param></xsl:call-template></b></font></td>
	<td bgcolor="#CCCCCC"><xsl:value-of select="$node/text()"/></td>
      </tr>
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template name="publicationStmt.misc">
    <xsl:param name="nodes"/>
    <xsl:param name="name"/>
    
    <xsl:if test="$nodes">
      <tr valign="top">
	<td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name" select="$name"/></xsl:call-template></b></font></td>
	<td bgcolor="#CCCCCC">
	  <xsl:for-each select="$nodes">
	    <xsl:value-of select="text()"/>
	    <xsl:call-template name="nbsp"/>
	  </xsl:for-each>
	</td>
      </tr>
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template name="publicationStmt.idno">
    <xsl:param name="nodes"/>
    
    <xsl:for-each select="$nodes">
      <tr valign="top">
	<td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:value-of select="@type"/>: </b></font></td>
	<td bgcolor="#CCCCCC"><xsl:value-of select="text()"/></td>
      </tr>
    </xsl:for-each>
  </xsl:template>
  

  <xsl:template match="availability" mode="ces.header">
    <xsl:variable name="availability.status" select="@status"/>

    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <xsl:choose>
	<xsl:when test="$availability.status">
	  <td bgcolor="#CCCCCC"><b><xsl:value-of select="$availability.status"/></b> - <i><xsl:value-of select="text()"/></i></td>
	</xsl:when>
	<xsl:otherwise>
	  <td bgcolor="#CCCCCC"><i><xsl:value-of select="text()"/></i></td>
	</xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="sourceDesc" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#FFFFFF">
	<table cellspacing="1" cellpadding="0" bgcolor="#FFFFFF" width="100%" border="0">
	  <xsl:apply-templates select="*" mode="ces.header"/>
	</table>
      </td></tr>
  </xsl:template>
  
  
  <xsl:template match="biblFull" mode="ces.header">
    <xsl:apply-templates select="*" mode="ces.header"/>
  </xsl:template>
  
  
  <xsl:template match="biblStruct" mode="ces.header">
    <xsl:apply-templates select="*" mode="ces.header"/>
  </xsl:template>
  
  
  <!-- encodingDesc section -->
  
  <xsl:template match="encodingDesc" mode="ces.header">
    <xsl:call-template name="cesheader.title"/>
    <table bgcolor="#CCCCCC" width="100%" border="0">
      <xsl:apply-templates select="*" mode="ces.header"/>
    </table>
  </xsl:template>
  

  <xsl:template match="projectDesc" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC" colspan="3"><xsl:value-of select="text()"/></td>
    </tr>
  </xsl:template>

  
  <xsl:template match="samplingDecl" mode="ces.header">
  </xsl:template>
  

  <xsl:template match="editorialDecl" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name">editorialDecl</xsl:with-param></xsl:call-template></b></font></td>
      <td colspan="3" bgcolor="#FFFFFF">
	<table bgcolor="#FFFFFF" width="100%" border="0">
	  <xsl:apply-templates select="*" mode="ces.header"/>
	</table>
      </td>
    </tr>    
  </xsl:template>
  

  <xsl:template match="conformance" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="text()"/> (level <xsl:value-of select="@level"/>)</td>
    </tr>
  </xsl:template>


  <xsl:template match="correction" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="@status"/>, <xsl:value-of select="@method"/></td>
    </tr>
  </xsl:template>


  <xsl:template match="quotation" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="text()"/> (marks=<xsl:value-of select="@marks"/>, form=<xsl:value-of select="@form"/></td>
    </tr>
  </xsl:template>


  <xsl:template match="segmentation|hyphenation|transduction" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="text()"/></td>
    </tr>
  </xsl:template>


  <xsl:template match="tagsDecl" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name">tagsDecl</xsl:with-param></xsl:call-template></b></font></td>
      <td colspan="3" bgcolor="#CCCCCC">&#160;</td>
    </tr>
    <xsl:apply-templates select="tagUsage" mode="ces.header"/>
  </xsl:template>
  

  <xsl:template match="tagUsage" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC">&#160;</td>
      <td bgcolor="#CCCCCC" align="left"><font face="Tahoma,Arial,Helvetica"><b><xsl:value-of select="@gi"/></b></font></td>
      <td bgcolor="#CCCCCC" align="center"><xsl:value-of select="@occurs"/></td>
      <td bgcolor="#CCCCCC" align="left"><xsl:value-of select="text()"/>&#160;</td>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="refsDecl" mode="ces.header">
    <xsl:call-template name="todo">
      <xsl:with-param name="what">refsDecl</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  
  <xsl:template match="classDecl" mode="ces.header">
    <xsl:call-template name="todo">
      <xsl:with-param name="what">classDecl</xsl:with-param>
    </xsl:call-template>
  </xsl:template>


  <!-- profileDesc section -->

  <xsl:template match="profileDesc" mode="ces.header">
    <xsl:call-template name="cesheader.title"/>
    <table bgcolor="#CCCCCC" width="100%" border="0">
      <xsl:apply-templates select="*" mode="ces.header"/>
    </table>
  </xsl:template>
  
  
  <xsl:template match="langUsage" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td colspan="3" bgcolor="#CCCCCC">&#160;</td>
    </tr>
    <xsl:apply-templates select="language" mode="ces.header"/>
  </xsl:template>
  
  
  <xsl:template match="language" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC">&#160;</td>
      <td bgcolor="#CCCCCC"><font face="Tahoma,Arial,Helvetica"><b><xsl:value-of select="text()"/>&#160;</b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="@id"/>&#160;</td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="@iso639"/>&#160;</td>
    </tr>
  </xsl:template>
  
  
  <xsl:template match="wsdUsage" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC" nowrap="nowrap" align="right" width="10%"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:call-template name="i18n.text"><xsl:with-param name="text.name"><xsl:value-of select="name()"/></xsl:with-param></xsl:call-template></b></font></td>
      <td colspan="3" bgcolor="#CCCCCC">&#160;</td>
    </tr>
    <xsl:apply-templates select="writingSystem" mode="ces.header"/>
  </xsl:template>
  
  <xsl:template match="writingSystem" mode="ces.header">
    <tr valign="top">
      <td bgcolor="#CCCCCC">&#160;</td>
      <td bgcolor="#CCCCCC"><font face="Tahoma,Arial,Helvetica"><b><xsl:value-of select="text()"/>&#160;</b></font></td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="@id"/>&#160;</td>
      <td bgcolor="#CCCCCC"><xsl:value-of select="@wsd"/>&#160;</td>
    </tr>
  </xsl:template>
  
  <!-- revisionDesc section -->

  <xsl:template match="revisionDesc" mode="ces.header">
    <xsl:variable name="nodes" select="change"/>
    
    <xsl:call-template name="cesheader.title"/>
    <xsl:if test="$nodes">
      <table bgcolor="#CCCCCC" width="100%" border="0">
	<xsl:apply-templates select="$nodes" mode="ces.header"/>
      </table>	  
    </xsl:if>
  </xsl:template>
  
  <xsl:template match="change" mode="ces.header">
    <xsl:variable name="nodes" select="h.item"/>    

    <tr>
      <td rowspan="0" colspan="0" valign="top"><font color="#007777" face="Tahoma,Arial,Helvetica"><b><xsl:apply-templates select="changeDate/text()"/></b></font></td>
      <td rowspan="0" colspan="0" valign="top"><i><xsl:apply-templates select="respName/text()"/></i></td>
      <td rowspan="0" colspan="0" align="left">
	<xsl:if test="$nodes">
	  <ul>
	  <xsl:for-each select="$nodes">
	    <li><xsl:apply-templates select="text()"/></li>
	  </xsl:for-each>
	  </ul>
	</xsl:if>
      </td>
    </tr>
  </xsl:template>
  
  
  <!-- Misc templates -->
  
  <xsl:template name="cesheader.title">
    <xsl:param name="elt.id"><xsl:call-template name="element.id"/></xsl:param>
    <xsl:param name="elt.name"><xsl:value-of select="name()"/></xsl:param>
    
    <h2><a name="{$elt.id}"></a><xsl:call-template name="i18n.text">
	  <xsl:with-param name="text.name" select="$elt.name"/>
	</xsl:call-template></h2>
  </xsl:template>
  
  
</xsl:stylesheet>

<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-default-dtd-file:"/local/led/share/dtd/xsl/xsl.ced"
End:
-->
