<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version='1.0'>
  
  <xsl:include href="table.xsl"/>
  
  <!-- bibl|byline|caption|figure|list|note|opener|p|poem|quote|sp|table -->
  
  
  <!-- Templates for paragraph elements in output.split mode -->
  
  
  <xsl:template match="bibl|byline|caption|figure|list|note|opener|p|poem|quote|sp|table"
		mode="output.split">
    <xsl:apply-templates select="."/>
  </xsl:template>
  
  
  <!-- Templates for paragraph elements without splitting -->
  
  
  <xsl:template match="opener">
    <xsl:apply-templates/>
  </xsl:template>
  
  
  <xsl:template match="note">
    <span style="border:1px solid black;color:#007777;">[NOTE: <xsl:apply-templates/>]</span>
  </xsl:template>
  

  <xsl:template match="note.todo">
    <xsl:variable name="name"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:variable name="href"><xsl:text>#note.</xsl:text><xsl:value-of select="$name"/></xsl:variable>
    
    <sup>
      <xsl:text>[</xsl:text>
      <a name="{$name}" href="{$href}">
	<xsl:apply-templates select="." mode="note.number"/>
      </a>
      <xsl:text>]</xsl:text>
    </sup>
  </xsl:template>
  
  
  <xsl:template match="note" mode="note.number">
    <xsl:number level="any" format="1"/>
  </xsl:template>
  
  
  <xsl:template match="figure">
    <xsl:variable name="img.alt"><xsl:call-template name="figure.figDesc"/></xsl:variable>
    <xsl:choose>
      <xsl:when test="@entity">
	<img border='0' src="{unparsed-entity-uri(@entity)}">
	  <xsl:if test="$img.alt">
	    <xsl:attribute name="alt"><xsl:value-of select="$img.alt"/></xsl:attribute>
	  </xsl:if>
	</img>
      </xsl:when>
      <xsl:otherwise> [IMG] </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="figure.figDesc">
    <xsl:variable name="img.alt" select="figDesc/text()"/>
    <xsl:choose>
      <xsl:when test="$img.alt"><xsl:value-of select="$img.alt"/></xsl:when>
      <xsl:otherwise><xsl:text>...</xsl:text></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template match="caption">
    <p><xsl:apply-templates/></p>
  </xsl:template>
  
  
  <xsl:template match="bibl">
    <p align="center"><b><xsl:apply-templates/></b></p>
  </xsl:template>


  <xsl:template match="byline">
    <xsl:text>[</xsl:text><xsl:apply-templates/><xsl:text>] </xsl:text>
  </xsl:template>
  
  
  <xsl:template match="list">
    <ul><xsl:apply-templates select="*"/></ul>
  </xsl:template>
  
  
  <xsl:template match="list/head">
    <li><u><xsl:value-of select="text()"/></u></li>
  </xsl:template>
  
  
  <xsl:template match="list/label"/>
  
  
  <!-- Contextual node : item -->
  <xsl:template name="list.label">
    <xsl:value-of select="preceding-sibling::label/text()"/>
  </xsl:template>
  
  
  <xsl:template match="item">
    <li>
      <xsl:if test="preceding-sibling::label">
        <xsl:call-template name="list.label"/>
        <xsl:call-template name="nbsp"/>
      </xsl:if>
      <xsl:apply-templates select="node()"/>
    </li>
  </xsl:template>
  
  
  <xsl:template match="p">
    <p><xsl:apply-templates select="node()"/></p>
  </xsl:template>
  
  
  <xsl:template match="poem">
    <div class="poem"><xsl:apply-templates select="*"/></div>
  </xsl:template>
  
  
  <xsl:template match="poem/head">
    <strong><xsl:apply-templates select="node()"/></strong><br/>
  </xsl:template>
  
  
  <xsl:template match="lg">
    <blockquote><xsl:apply-templates select="*"/></blockquote>
  </xsl:template>
  
  
  <xsl:template match="l">
    <xsl:apply-templates select="node()"/><br/>
  </xsl:template>
  
  
  <xsl:template match="quote">
    <blockquote><cite><xsl:apply-templates select="*"/></cite></blockquote>
  </xsl:template>
  
  
  <xsl:template match="sp">
    <xsl:choose>
      <xsl:when test="@who">
	<i><xsl:value-of select="@who"/></i>
	<xsl:call-template name="sp.sep"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:choose>
	  <xsl:when test="speaker">
	    <i><xsl:apply-templates select="speaker" mode="speaker"/></i>
	    <xsl:call-template name="sp.sep"/>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:text>-</xsl:text><xsl:call-template name="nbsp"/>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
    
    
    <xsl:if test="speaker">
      <xsl:apply-templates select="p" mode="speaker"/>
    </xsl:if>
    <xsl:if test="stage">
      <i> [<xsl:apply-templates select="stage" mode="speaker"/>]</i>
    </xsl:if>
    <br/>
  </xsl:template>
  
  
  <xsl:template match="p" mode="speaker">
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  
  
  <xsl:template match="stage" mode="speaker">
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  
  
</xsl:stylesheet>

<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-default-dtd-file:"/local/led/share/dtd/xsl/xsl.ced"
End:
-->
